summaryrefslogtreecommitdiffhomepage
path: root/dev/kernel/src/FS
diff options
context:
space:
mode:
Diffstat (limited to 'dev/kernel/src/FS')
-rw-r--r--dev/kernel/src/FS/NeFS+FileSystemParser.cc6
-rw-r--r--dev/kernel/src/FS/OpenHeFS+FileMgr.cc (renamed from dev/kernel/src/FS/HeFS+FileMgr.cc)20
-rw-r--r--dev/kernel/src/FS/OpenHeFS+FileSystemParser.cc (renamed from dev/kernel/src/FS/HeFS+FileSystemParser.cc)18
3 files changed, 22 insertions, 22 deletions
diff --git a/dev/kernel/src/FS/NeFS+FileSystemParser.cc b/dev/kernel/src/FS/NeFS+FileSystemParser.cc
index 14e0b974..b50841a4 100644
--- a/dev/kernel/src/FS/NeFS+FileSystemParser.cc
+++ b/dev/kernel/src/FS/NeFS+FileSystemParser.cc
@@ -74,7 +74,7 @@ static inline bool is_valid_lba(Lba lba, DriveTrait& drive) {
return (lba >= part_block.StartCatalog) && (lba < maxLba);
}
-STATIC MountpointInterface kMountpoint;
+STATIC IMountpoint kMountpoint;
/***********************************************************************************/
/// @brief Creates a new fork inside the New filesystem partition.
/// @param catalog it's catalog
@@ -141,7 +141,7 @@ _Output BOOL NeFileSystemParser::CreateFork(_Input NEFS_FORK_STRUCT& the_fork) {
drv.fPacket.fPacketContent = reinterpret_cast<VoidPtr>(&the_fork);
drv.fOutput(drv.fPacket);
- fs_ifs_write(&kMountpoint, drv, MountpointInterface::kDriveIndexA);
+ fs_ifs_write(&kMountpoint, drv, IMountpoint::kDriveIndexA);
delete catalog;
return YES;
@@ -858,7 +858,7 @@ namespace Kernel::NeFS {
/// @brief Construct NeFS drives.
/***********************************************************************************/
Boolean fs_init_nefs(Void) noexcept {
- kout << "Creating HeFS disk...\r";
+ kout << "Creating OpenHeFS disk...\r";
kMountpoint.A() = io_construct_main_drive();
if (kMountpoint.A().fPacket.fPacketReadOnly == YES)
ke_panic(RUNTIME_CHECK_FILESYSTEM, "Main disk cannot be mounted.");
diff --git a/dev/kernel/src/FS/HeFS+FileMgr.cc b/dev/kernel/src/FS/OpenHeFS+FileMgr.cc
index 33813f65..bb87fd67 100644
--- a/dev/kernel/src/FS/HeFS+FileMgr.cc
+++ b/dev/kernel/src/FS/OpenHeFS+FileMgr.cc
@@ -10,7 +10,7 @@
#include <KernelKit/FileMgr.h>
#include <KernelKit/HeapMgr.h>
/// @brief HeFS File System Manager.
/// BUGS: 0
namespace Kernel {
@@ -35,7 +35,7 @@ HeFileSystemMgr::~HeFileSystemMgr() {
/// @return If it was deleted or not.
bool HeFileSystemMgr::Remove(_Input const Char* path) {
if (path == nullptr || *path == 0) {
- kout << "HeFS: Remove called with null or empty path\n";
+ kout << "OpenHeFS: Remove called with null or empty path\n";
return false;
}
@@ -47,7 +47,7 @@ bool HeFileSystemMgr::Remove(_Input const Char* path) {
/// @return The Node pointer.
NodePtr HeFileSystemMgr::Create(_Input const Char* path) {
if (!path || *path == 0) {
- kout << "HeFS: Create called with null or empty path\n";
+ kout << "OpenHeFS: Create called with null or empty path\n";
return nullptr;
}
return nullptr;
@@ -58,7 +58,7 @@ NodePtr HeFileSystemMgr::Create(_Input const Char* path) {
/// @return The Node pointer.
NodePtr HeFileSystemMgr::CreateDirectory(const Char* path) {
if (!path || *path == 0) {
- kout << "HeFS: CreateDirectory called with null or empty path\n";
+ kout << "OpenHeFS: CreateDirectory called with null or empty path\n";
return nullptr;
}
return nullptr;
@@ -69,7 +69,7 @@ NodePtr HeFileSystemMgr::CreateDirectory(const Char* path) {
/// @return The Node pointer.
NodePtr HeFileSystemMgr::CreateAlias(const Char* path) {
if (!path || *path == 0) {
- kout << "HeFS: CreateAlias called with null or empty path\n";
+ kout << "OpenHeFS: CreateAlias called with null or empty path\n";
return nullptr;
}
return nullptr;
@@ -77,7 +77,7 @@ NodePtr HeFileSystemMgr::CreateAlias(const Char* path) {
NodePtr HeFileSystemMgr::CreateSwapFile(const Char* path) {
if (!path || *path == 0) {
- kout << "HeFS: CreateSwapFile called with null or empty path\n";
+ kout << "OpenHeFS: CreateSwapFile called with null or empty path\n";
return nullptr;
}
return nullptr;
@@ -104,7 +104,7 @@ Char NeFileSystemHelper::Separator() {
/// @brief Gets the metafile character.
/// @return
Char NeFileSystemHelper::MetaFile() {
- return 0;
+ return '\0';
}
/// @brief Opens a new file.
@@ -113,11 +113,11 @@ Char NeFileSystemHelper::MetaFile() {
/// @return
_Output NodePtr HeFileSystemMgr::Open(_Input const Char* path, _Input const Char* r) {
if (!path || *path == 0) {
- kout << "HeFS: Open called with null or empty path\n";
+ kout << "OpenHeFS: Open called with null or empty path\n";
return nullptr;
}
if (!r || *r == 0) {
- kout << "HeFS: Open called with null or empty mode string\n";
+ kout << "OpenHeFS: Open called with null or empty mode string\n";
return nullptr;
}
return nullptr;
@@ -181,7 +181,7 @@ _Output Bool HeFileSystemMgr::Rewind(NodePtr node) {
return kFileMgrNPos;
}
/// @brief Returns the parser of HeFS.
_Output HeFileSystemParser* HeFileSystemMgr::GetParser() noexcept {
return mParser;
}
@@ -10,7 +10,7 @@
#include <KernelKit/FileMgr.h>
#include <KernelKit/HeapMgr.h>
-/// @brief HeFS File System Manager.
+/// @brief OpenHeFS File System Manager.
/// BUGS: 0
namespace Kernel {
@@ -181,7 +181,7 @@ _Output Bool HeFileSystemMgr::Rewind(NodePtr node) {
return kFileMgrNPos;
}
-/// @brief Returns the parser of HeFS.
+/// @brief Returns the parser of OpenHeFS.
_Output HeFileSystemParser* HeFileSystemMgr::GetParser() noexcept {
return mParser;
diff --git a/dev/kernel/src/FS/HeFS+FileSystemParser.cc b/dev/kernel/src/FS/OpenHeFS+FileSystemParser.cc
index 029fdf26..3746ebc1 100644
--- a/dev/kernel/src/FS/HeFS+FileSystemParser.cc
+++ b/dev/kernel/src/FS/OpenHeFS+FileSystemParser.cc
@@ -6,7 +6,7 @@
#ifdef __FSKIT_INCLUDES_HEFS__
-#include <FSKit/HeFS.h>
+#include <FSKit/OpenHeFS.h>
#include <FirmwareKit/EPM.h>
#include <FirmwareKit/GPT.h>
#include <KernelKit/KPC.h>
@@ -79,7 +79,7 @@ namespace Detail {
const Utf8Char* dir_name, UInt16 flags,
const BOOL delete_or_create);
/// @brief This helper makes it easier for other machines to understand HeFS encoded hashes.
STATIC UInt64 hefsi_to_big_endian_64(UInt64 val) {
return ((val >> 56) & 0x00000000000000FFULL) | ((val >> 40) & 0x000000000000FF00ULL) |
((val >> 24) & 0x0000000000FF0000ULL) | ((val >> 8) & 0x00000000FF000000ULL) |
@@ -743,12 +743,12 @@ namespace Detail {
} // namespace Detail
} // namespace Kernel
/// @note HeFS will allocate inodes and ind in advance, to avoid having to allocate them in
/// real-time.
/// @note This is certainly take longer to format a disk with it, but worth-it in the long run.
namespace Kernel {
/// @brief Make a EPM+HeFS mnt out of the disk.
/// @param mnt The mnt to write on.
/// @return If it was sucessful, see err_local_get().
_Output Bool HeFileSystemParser::Format(_Input _Output DriveTrait* mnt, _Input const Int32 flags,
@@ -766,7 +766,7 @@ _Output Bool HeFileSystemParser::Format(_Input _Output DriveTrait* mnt, _Input c
(Void)(kout << "OpenHeFS recommends at least 128 GiB of free space." << kendl);
(Void)(
kout
- << "The OS will still try to format a HeFS disk here anyway, don't expect perfect geometry."
+ << "The OS will still try to format a OpenHeFS disk here anyway, don't expect perfect geometry."
<< kendl);
}
@@ -822,7 +822,7 @@ _Output Bool HeFileSystemParser::Format(_Input _Output DriveTrait* mnt, _Input c
MUST_PASS(boot->fSectorSize);
/// @note all HeFS strucutres are equal to 512, so here it's fine, unless fSectoSize is 2048.
const SizeT max_lba = (drv_std_get_size()) / boot->fSectorSize;
const SizeT dir_max = max_lba / 300; // 5% for directory inodes
@@ -1007,7 +1007,7 @@ _Output Bool HeFileSystemParser::INodeManip(_Input DriveTrait* mnt, VoidPtr bloc
mnt->fInput(mnt->fPacket);
if (!KStringBuilder::Equals(boot->fMagic, kHeFSMagic) || boot->fVersion != kHeFSVersion) {
- (Void)(kout << "Invalid Boot Node, HeFS partition is invalid." << kendl);
+ (Void)(kout << "Invalid Boot Node, OpenHeFS partition is invalid." << kendl);
mm_free_ptr((VoidPtr) boot);
err_global_get() = kErrorDisk;
return NO;
@@ -1147,9 +1147,9 @@ _Output Bool HeFileSystemParser::INodeCtlManip(_Input DriveTrait* mnt, _Input co
STATIC DriveTrait kMountPoint;
/// @brief Initialize the HeFS filesystem.
/// @return To check its status, see err_local_get().
-Boolean HeFS::fs_init_hefs(Void) noexcept {
+Boolean OpenHeFS::fs_init_hefs(Void) noexcept {
kout << "Verifying disk...\r";
kMountPoint = io_construct_main_drive();
@@ -79,7 +79,7 @@ namespace Detail {
const Utf8Char* dir_name, UInt16 flags,
const BOOL delete_or_create);
- /// @brief This helper makes it easier for other machines to understand HeFS encoded hashes.
+ /// @brief This helper makes it easier for other machines to understand OpenHeFS encoded hashes.
STATIC UInt64 hefsi_to_big_endian_64(UInt64 val) {
return ((val >> 56) & 0x00000000000000FFULL) | ((val >> 40) & 0x000000000000FF00ULL) |
@@ -743,12 +743,12 @@ namespace Detail {
} // namespace Detail
} // namespace Kernel
-/// @note HeFS will allocate inodes and ind in advance, to avoid having to allocate them in
+/// @note OpenHeFS will allocate inodes and ind in advance, to avoid having to allocate them in
/// real-time.
/// @note This is certainly take longer to format a disk with it, but worth-it in the long run.
@@ -743,12 +743,12 @@ namespace Detail {
/// @note This is certainly take longer to format a disk with it, but worth-it in the long run.
namespace Kernel {
-/// @brief Make a EPM+HeFS mnt out of the disk.
+/// @brief Make a EPM+OpenHeFS mnt out of the disk.
/// @param mnt The mnt to write on.
/// @return If it was sucessful, see err_local_get().
@@ -822,7 +822,7 @@ _Output Bool HeFileSystemParser::Format(_Input _Output DriveTrait* mnt, _Input c
MUST_PASS(boot->fSectorSize);
- /// @note all HeFS strucutres are equal to 512, so here it's fine, unless fSectoSize is 2048.
+ /// @note all OpenHeFS strucutres are equal to 512, so here it's fine, unless fSectoSize is 2048.
const SizeT max_lba = (drv_std_get_size()) / boot->fSectorSize;
const SizeT dir_max = max_lba / 300; // 5% for directory inodes
@@ -1147,9 +1147,9 @@ _Output Bool HeFileSystemParser::INodeCtlManip(_Input DriveTrait* mnt, _Input co
STATIC DriveTrait kMountPoint;
-/// @brief Initialize the HeFS filesystem.
+/// @brief Initialize the OpenHeFS filesystem.
/// @return To check its status, see err_local_get().